/*  Copyright (c) 2008 Tomasz Moń <desowin@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; under version 3 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses>.
 */

#include <gtk/gtk.h>
#include <gdk/gdkx.h>
#include <X11/extensions/scrnsaver.h>
#include <config.h>

#include "autoaway.h"
#include "riv.h"
#include "net.h"
#include "conf.h"

gboolean autoaway = FALSE;
guint event_id = 0;

gboolean check_away(gpointer data) {
#ifdef GDK_WINDOWING_X11
    int idle, event, error;
    XScreenSaverInfo* info;
    if (XScreenSaverQueryExtension(GDK_DISPLAY(), &event, &error)) {
        info = XScreenSaverAllocInfo();
        XScreenSaverQueryInfo(GDK_DISPLAY(), GDK_ROOT_WINDOW(), info);
        idle = info->idle / 1000; /* seconds */
        XFree(info);
    } else
        idle = 0;

    if (idle > conf.away_timeout) {
        if (!autoaway) {
#ifdef DEBUG
            printf("entering autoaway\n");
#endif
            autoaway = TRUE;
            send_ping();
        }
    } else if (autoaway) {
#ifdef DEBUG
        printf("leaving autoaway\n");
#endif
        autoaway = FALSE;
        send_ping();
    }

    return TRUE;
#else
    event_id = 0;
    return FALSE;
#endif
}

void autoaway_start() {
    event_id = g_timeout_add_seconds(10, check_away, NULL);
}

void autoaway_stop() {
    if (event_id)
        g_source_remove(event_id);
    event_id = 0;
}
